Name:       gnome-shell-extension-freon
Summary:    GNOME Shell extension to display system temperature, voltage, and fan speed
Epoch:      1
Version:    35
Release:    3%{?dist}
URL:        https://github.com/UshakovVasilii/gnome-shell-extension-freon/wiki
License:    GPLv2
BuildArch:  noarch

# You can see the latest source releases here:
# https://github.com/UshakovVasilii/gnome-shell-extension-freon/releases
Source0: https://github.com/UshakovVasilii/%{name}/archive/EGO-%{version}/%{name}-EGO-%{version}.tar.gz
Source1: ./README.md

# Dependencies described here:
# https://github.com/UshakovVasilii/gnome-shell-extension-freon/wiki/Dependency
Requires: gnome-shell >= 3.30
Requires: gnome-shell-extension-common
Requires: lm_sensors
Requires: udisks2

Recommends: gnome-tweaks


%description
Freon is a GNOME Shell extension for displaying the temperature of your CPU,
hard disk, solid state, and video card (NVIDIA, Catalyst, and Bumblebee
supported), as well as power supply voltage, and fan speed. You can choose which
HDD/SSD or other devices to include, what temperature units to use, and how
often to refresh the sensors readout, and they will appear in the GNOME Shell
top bar.

**NOTE** that if you want to see GPU temperature, you will need to
install the vendor's driver and any related packages. (Nouveau
unfortunately won't work for Nvidia cards.)

* hard drive temperatures require either `udisks2`, or both `hddtemp`
  and `netcat` (udisks2 should already be installed with this package,
  but if you want to use hddtemp instead, you will need to install it
  and netcat yourself)
* Nvidia GPU temperatures require the `nvidia-settings` application,
  typically installed with the proprietary Nvidia drivers
* AMD GPU temperatures requires `aticonfig`, part of AMD Radeon Software
  (formerly known as AMD Catalyst)
* Bumblebee + Nvidia requires `optirun`



# UUID is defined in extension's metadata.json and used as directory name.
%global  UUID                  freon@UshakovVasilii_Github.yahoo.com
%global  gnome_extensions_dir  %{_datadir}/gnome-shell/extensions/
%global  final_install_dir     %{buildroot}/%{gnome_extensions_dir}/%{UUID}

%prep
%autosetup -n %{name}-EGO-%{version}

%build
# No compilation necessary.

%install
mkdir -p %{final_install_dir}
cp --recursive --preserve=mode,timestamps  %{UUID}/*  %{final_install_dir}
cp --recursive --preserve=mode,timestamps  %{SOURCE1}  ./README-fedora.md

# RPM will take care of gschemas, we don't need to include a precompiled copy.
mkdir -p %{buildroot}/%{_datadir}/glib-2.0/schemas/
mv  %{final_install_dir}/schemas/org.gnome.shell.extensions.sensors.gschema.xml  \
    %{buildroot}/%{_datadir}/glib-2.0/schemas/
rm --recursive %{final_install_dir}/schemas/

# Remove source .po localization files, move binary .mo to system directory.
rm --recursive %{final_install_dir}/po/
mv  %{final_install_dir}/locale  %{buildroot}/%{_datadir}/
%find_lang freon



%files -f freon.lang
%doc README.md  README-fedora.md
%license LICENSE
%{gnome_extensions_dir}/%{UUID}/
%{_datadir}/glib-2.0/schemas/org.gnome.shell.extensions.sensors.gschema.xml



%changelog
* Mon Apr 08 2019 Andrew Toskin <andrew@tosk.in> - 1:35-3
- Pushing version 36 to Fedora 29 was a mistake, as Freon 36 doesn't
  work on GNOME 3.30. But it's too late to "unpush" so I'm bumping the
  Epoch to revert to Freon 35 for Fedora 29.

* Tue Mar 26 2019 Andrew Toskin <andrew@tosk.in> - 36-1
- Bump to upstream version 36, which offers several bugfixes and
  improvements, including allowing Freon to better recover if
  underlying sensors software crashes, and updating for latest support
  for NVME SmartCtl.
  <https://github.com/UshakovVasilii/gnome-shell-extension-freon/compare/EGO-35...EGO-36>

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 35-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Nov 14 2018 Andrew Toskin <andrew@tosk.in> - 35-1
- Bump to upstream version 35, which fixes the German translation and
  some gjs errors, but now only supports GNOME 3.30.

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 34-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed May 16 2018 Andrew Toskin <andrew@tosk.in> - 34-1
- Bump to upstream version 34, which improves the Polish and Spanish
  translations, and fixed a bug where it did not check for Nvidia
  lockfiles.

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 33-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Jan 22 2018 Andrew Toskin <andrew@tosk.in> - 33-1
- Bump to upstream version 33, which fixes typos in the Russian and
  Ukrainian locales, and fixes an instability issue that could cause GNOME
  Shell to crash.
